#
# spec file for package bolt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _hardened_build 1
Name:           bolt
Version:        0.9.8
Release:        3.4
Summary:        Thunderbolt 3 device manager
License:        LGPL-2.1-or-later
Group:          System/Daemons
URL:            https://gitlab.freedesktop.org/bolt/bolt
Source0:        https://gitlab.freedesktop.org/bolt/bolt/-/archive/%{version}/bolt-%{version}.tar.bz2
BuildRequires:  asciidoc
BuildRequires:  c_compiler
BuildRequires:  meson >= 0.60
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.56.0
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(udev)

%description
Userspace system daemon to enable security levels for Thunderbolt 3
on GNU/Linux.

%package        tools
Summary:        Bolt Tools
Group:          System/Management
Requires:       %{name} = %{version}-%{release}

%description    tools
The %{name}-tools package contains optional tools from the Bolt
software framework.

%prep
%autosetup

%build
%meson
%meson_build

%check
%meson_test

%install
%meson_install

# move polkit rules to doc folder: the wheel group does not have special
# meaning on SUSE based distros
mkdir -p %{buildroot}/%{_docdir}/bolt/
mv %{buildroot}%{_datadir}/polkit-1/rules.d/org.freedesktop.bolt.rules %{buildroot}/%{_docdir}/bolt/

%preun
%service_del_preun bolt.service

%post
%service_add_post bolt.service

%postun
%service_del_postun bolt.service

%pre
%service_add_pre bolt.service

%files
%doc README.md INSTALL.md BUGS.md
%license COPYING
%{_mandir}/man8/boltd.8%{?ext_man}
%{_libexecdir}/boltd
%{_unitdir}/bolt.service
%{_datadir}/dbus-1/system.d/org.freedesktop.bolt.conf
%{_datadir}/polkit-1/actions/org.freedesktop.bolt.policy
%{_udevrulesdir}/90-bolt.rules
%{_datadir}/dbus-1/interfaces/org.freedesktop.bolt.xml
%{_datadir}/dbus-1/system-services/org.freedesktop.bolt.service
%{_docdir}/bolt/org.freedesktop.bolt.rules

%files tools
%{_bindir}/boltctl
%{_mandir}/man1/boltctl.1%{?ext_man}

%changelog
* Wed Oct 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop rcFOO symlinks (PED-266).
* Sat Jun 29 2024 Enrico Belleri <kilgore.trout@idesmi.eu>
- Edit license: LGPL-2.1-or-later
- Add BuildRequires: asciidoc to produce manpages:
  * boltd.8 boltctl.1
- Switch dependencies to provided pkgconfig
- Update meson required version 0.60
- Use autosetup
* Thu May 16 2024 Robert Frohl <rfrohl@suse.com>
- update to 0.9.8:
  * A new NHI for REMBRANDT.
  * CI fixes.
  * Don't install an empty DB directory.
  * Fixed: Determine the string length before writing file.
  * Fixed: Free on error to prevent resource leak.
* Mon Feb 19 2024 Robert Frohl <rfrohl@suse.com>
- update to 0.9.7:
  * Add a 'nopcie' security level since some devices report nopcie when Thunderbolt
    is disabled through BIOS setting.
  * Markdown lint styling is used for documents.
* Tue Oct  3 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 0.9.6:
  * Compiler warnings and log messages for the domain not found were fixed.
* Wed Jan  4 2023 Robert Frohl <rfrohl@suse.com>
- update to 0.9.5:
  * Fixed several test and build setting issues.
  * Introduced packit. Packit was used to package rpm to downstream Fedora
    automatically. Moreover, Koji and bodhi could be triggered by packit
    automatically.
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.4:
  * spec file added and a few metadata fixes, no code change
* Wed Aug 24 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.9.3:
  * Work around a glib fix that changed behavior of the log API where now
    calling `g_log_set_writer_func` results in an hard error, which broke
    the test suite since aforementioned function was indeed called more
    than once. Nothing a level of indirection couldn't fix.
* Fri Jan 28 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.9.2
  * This release is compatible with umockdev >= 0.16.3; there was a change in
    umockdev that made our test fail with it, since both our test and umockev
    were trying to create the same directorires. bolt now allows for the dir
    to already exist.
  * The license for `90-bolt.rules` has changed from `GPL-2.1+`, which does
    not exist and was probably was confused with `LGPL-2.1+`, to `GPL 2.0+`.
  * Documentation has been updated and spelling mistakes fixed.
  * Various improvements for continuous integration.
  * The minimum required version of meson has been bumped to 0.46.0.
* Tue Sep 28 2021 Oliver Neukum <oneukum@suse.com>
- Need in SLE
  * Support for working with adapters without ROMs is needed
    (jsc#SLE-19359)
* Wed Jun  2 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.9.1
  * Support Ice Lake Thunderbolt 3 i/o subsystem
  * Don't store domains where uuids change across reboots
  * Fixes for the journal and the domain's acl-log
  * Version the store and use that to clean up stale domains once
  * Host identification for embedded thunderbolt controllers [!233]
  * Various other small bug fixes and memory leak fixes.
* Tue Jun 16 2020 Robert Frohl <rfrohl@suse.com>
- Update to 0.9
  * New Features:
  - Add 'Generation' attribute for the Manager
  - Ability to change the policy of a stored device
  - The BootACL Domain property is now writable
  - Support for systemd's service watchdog
  - Expose Link Speed sysfs attributes
  * Improvements:
  - boltclt: show timestamps in 'monitor' call
  - Persist the host device
  * Bug fixes:
  - Plug small memory leaks in error conditions
  - Ignore spurious wakeup device uevents for probing
  - Preserve keystate when updating devices
* Tue Dec 24 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut though the -mini flavors (complete previos change).
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libudev) instead of libudev-devel:
  Allow OBS to shortcut through the -mini flavors.
* Sun Jun 16 2019 Robert Frohl <rfrohl@suse.com>
- Update to 0.8
  * New Features:
  - IOMMU support: adapt behavior iommu support is present and active
  * automatically enroll new devices with the new iommu policy when iommu is active
  * automatically authorize devices with the iommu policy if iommu is active
  - boltctl config command to describe, get and set global, device and domain properties.
  - Chain authorization and enrollment via boltctl {enroll, authorize} --chain
  - bolt-mock script for interactively testing boltd
  * Improvements:
  - Automatically import devices that were authorized at boot
  - Make tests installable
  - Honour STATE_DIRECTORY and RUNTIME_DIRECTORY
  - Profiling support via gprof
  * Bug fixes:
  - Better handling of random data generation, removed hardening_for_RNG_code.patch
  - Fix double free in case of client creation failure
  - Fix invalid format string in warning
  - dbus configuration moved /usr/share
* Fri Feb 22 2019 Robert Frohl <rfrohl@suse.com>
- Move polkit rules file to into doc folder. The 'wheel' group has no special
  privileges and the file did not have any effect. (boo#1125425)
* Mon Jan  7 2019 Robert Frohl <rfrohl@suse.com>
- use meson macros during build
* Mon Jan  7 2019 Robert Frohl <rfrohl@suse.com>
- Update to 0.7
  * Features:
  - announce status to systemd via sd_notify (using a simple custom implementation)
  * Bug fixes:
  - properly update global security level status
  - adapt to systemd 240 not sending bind/unbind uevents
  - fix compilation on musl
  - daemon: use g_unix_signal_source… to catch signals
  * Improvements
  - precondition checks cleanup and completion
  - error cleanup
  - fix some leaks and issues uncovered by coverity
* Fri Jan  4 2019 Robert Frohl <rfrohl@suse.com>
- security review: add RNG hardening patch (boo#1119975):
  hardening_for_RNG_code.patch
* Mon Dec 10 2018 Robert Frohl <rfrohl@suse.com>
  Update to 0.6
- New Features:
  * pre-boot access control list, aka. BootACL support
  - domains objects are now persistent
  * new Uid (dbus) / uid (object) property derived from the uuid of the device representing the root switch
  * sysfs and id attribute will be set/unset on connects and disconnects
  * domains are now stored in the boltd database
  - domains got the BootACL (dbus) / bootacl (object) property
  * uuids can be added, removed or set in batch
  * when domain is online: changes are written to the sysfs boot_acl attribute directly
  * when domain is offline: changes are written to a journal and then reapplied in order when the domain is connected
  - newly enrolled devices get added to all bootacls of all domains if the policy is BOLT_POLICY_AUTO
  - removed devices get deleted from all bootacls of all domains
  - boltacl domain command will show the bootacl slots and their content
  * boltctl gained the -U, --uuid option, to control how uuids are printed
- Improvements and fixes:
  * Testing
  - boltctl is now included in the tests
  * Bugs and robustness:
  - The device state is verified in Device.Authorize
  - Handle empty 'keys' sysfs device attribute
  - Properly adjust policies when enrolling already authorized devices
  - Fix potential crasher when logging assertions g_return_if_fail
